Name:           backup-manager
Version:        0.7.16
Release:        %mkrel 4
Summary:        A command line backup tool for GNU/Linux

Group:          Archiving/Backup
License:        GPLv2+
URL:            https://github.com/sukria/Backup-Manager/
Source0:        https://github.com/sukria/Backup-Manager/archive/%{version}/Backup-Manager-%{version}.tar.gz
BuildArch:      noarch

BuildRequires:  gettext
Requires:       util-linux-ng
Requires:       bc
Requires:       bzip2
Requires:       diffutils
Requires:       less
Requires:       gettext
Requires:       gnupg
Requires:       gzip
Requires:       openssh-clients
Requires:       rsync
Requires:       sed
Requires:       tar
Requires:       which
Recommends:     cdrkit-genisoimage
Recommends:     cdrkit
Recommends:     dvd+rw-tools
Recommends:     dar

%description
Backup Manager is a command line backup tool for GNU/Linux, designed to help
you make daily archives of your file system. Written in bash and Perl, it can
make archives in lots of open formats (tar, gzip, bzip2, lzma, dar, zip) and
provides lots of interesting features (such as network exports or CD/DVD
automated-burning).

The program is designed to be as easy to use as possible and is popular with
desktop users and sysadmins. The whole backup process is defined in one
full-documented configuration file which needs no more than 5 minutes to tune
for your needs.

%prep
%setup -q -n Backup-Manager-%{version}

# Clean Makefile
sed -i -e "s@install -o root -g 0 @install @" Makefile

# rpmlint W: file-not-utf8
for file in  ChangeLog THANKS; do
    iconv -f ISO_8859-1 -t UTF-8 -o ${file}{.utf8,}
    mv ${file}{.utf8,}
done;

%build
%make_build PREFIX=%{_prefix}

%install
%make_install PREFIX=%{_prefix} PERL5DIR=%{perl_vendorlib}

%find_lang %{name}

# Create backup directory
install -d %{buildroot}%{_localstatedir}/lib/%{name}

# Copy configuration
install -p -D -m 0644 %{buildroot}%{_datadir}/%{name}/%{name}.conf.tpl \
    %{buildroot}%{_sysconfdir}/%{name}.conf
perl -pi \
    -e 's|BM_REPOSITORY_ROOT="/var/archives"|BM_REPOSITORY_ROOT="%{_localstatedir}/lib/%{name}"|' \
    %{buildroot}%{_sysconfdir}/%{name}.conf

# Add cron.daily
install -d -m 755 %{buildroot}%{_sysconfdir}/cron.daily/
cat > %{buildroot}%{_sysconfdir}/cron.daily/%{name} <<EOF
#!/bin/sh
%{_sbindir}/%{name} -v
EOF
chmod 755 %{buildroot}%{_sysconfdir}/cron.daily/%{name}

%files -f %{name}.lang
%doc AUTHORS ChangeLog COPYING NEWS README.md THANKS
%{_bindir}/%{name}-purge
%{_bindir}/%{name}-upload
%{_sbindir}/%{name}
%{perl_vendorlib}/BackupManager
%{_datadir}/%{name}/
%{_prefix}/lib/%{name}/
%{_mandir}/man8/%{name}*
%config(noreplace) %{_sysconfdir}/%{name}.conf
%{_sysconfdir}/cron.daily/%{name}
%{_localstatedir}/lib/%{name}


%changelog
* Fri Jun 27 2025 umeabot <umeabot> 0.7.16-4.mga10
+ Revision: 2205616
- Mageia 10 Mass Rebuild
+ danf <danf>
- Fix URL

* Mon Mar 21 2022 umeabot <umeabot> 0.7.16-3.mga9
+ Revision: 1811737
- Mageia 9 Mass Rebuild

* Sat Feb 15 2020 umeabot <umeabot> 0.7.16-2.mga8
+ Revision: 1526927
- Mageia 8 Mass Rebuild

* Sat Jul 06 2019 guillomovitch <guillomovitch> 0.7.16-1.mga8
+ Revision: 1419039
- new version 0.7.16 (unpublished yet)
- drop soft dependency on kerberos client applications
- turn hard dependency on dar to a soft one
- drop localized summaries and descriptions

* Thu Sep 20 2018 umeabot <umeabot> 0.7.15-2.mga7
+ Revision: 1277630
- Mageia 7 Mass Rebuild

* Sat Jul 07 2018 daviddavid <daviddavid> 0.7.15-1.mga7
+ Revision: 1242474
- new version: 0.7.15

* Fri Jan 05 2018 daviddavid <daviddavid> 0.7.14-1.mga7
+ Revision: 1190375
- new version: 0.7.14

* Wed Jul 19 2017 guillomovitch <guillomovitch> 0.7.13-2.mga7
+ Revision: 1125153
- fix modules location registered at installation time
+ daviddavid <daviddavid>
- no need to use our compile flags

* Fri Jan 27 2017 daviddavid <daviddavid> 0.7.13-1.mga6
+ Revision: 1083601
- new version: 0.7.13
- use our compile flags

* Sat Jun 18 2016 pterjan <pterjan> 0.7.11-2.mga6
+ Revision: 1022099
- Rebuild for perl 5.22.2

* Mon Dec 28 2015 guillomovitch <guillomovitch> 0.7.11-1.mga6
+ Revision: 916619
- new version 0.7.11
- drop implicit dependencies, switch non-mandatory ones to optional dependencies
- use /var/lib/backup-manager as default backup location

* Wed Oct 15 2014 umeabot <umeabot> 0.7.10-8.mga5
+ Revision: 748301
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.7.10-7.mga5
+ Revision: 678096
- Mageia 5 Mass Rebuild

* Tue Oct 22 2013 umeabot <umeabot> 0.7.10-6.mga4
+ Revision: 545796
- Mageia 4 Mass Rebuild

* Thu Oct 17 2013 luigiwalser <luigiwalser> 0.7.10-5.mga4
+ Revision: 501824
- add patch from fedora to fix POD syntax

* Fri Jan 11 2013 umeabot <umeabot> 0.7.10-4.mga3
+ Revision: 346827
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Oct 26 2012 malo <malo> 0.7.10-3.mga3
+ Revision: 310362
- fix RPM group

* Thu Jan 05 2012 matteo <matteo> 0.7.10-2.mga2
+ Revision: 191865
+ rebuild (emptylog)

* Sat Nov 26 2011 matteo <matteo> 0.7.10-1.mga2
+ Revision: 171980
- fixed ftp and perl requires
- fixed some rpmlint warnings
- imported package backup-manager

